*****
Readme:
*****

======
Section 1; Changelog:
======

-Version 1.0.0: Base package

-Version 1.1.0: Added some debugging functionality

-Version 1.1.1: Fixed path issue, and expanded upon debugging. Also implemented some doc-strings to guide!

-Version 1.1.2: Generalized path handling. Improved some doc-strings.